from distutils.core import setup

setup(
    name ='nester_rl',
    version='1.4.0',
    py_modules=['nester_rl'],
    author='hfpython',
    author_email='hfpython@headfirstlabs.com',
    url='http://www.headfirstlabs.com',
    description='A simple printer of nester lists',
    )
